@@ -151,7 +151,7 @@ from subunit.v2 import ByteStreamToStreamResult, StreamResultToBytes
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
 
-__version__ = (1, 4, 1, 'final', 0)
+__version__ = (1, 4, 2, 'final', 0)
 
 PROGRESS_SET = 0
 PROGRESS_CUR = 1
@@ -1252,11 +1252,9 @@ def read_test_list(path):
     :param path: Path to the file
     :return: Sequence of test ids
     """
-    f = open(path, 'rb')
-    try:
-        return [l.rstrip("\n") for l in f.readlines()]
-    finally:
-        f.close()
+    with open(path, 'r') as f:
+        return [line.split('#')[0].rstrip() for line in f.readlines()
+                if line.split('#')[0]]
 
 
 def make_stream_binary(stream):
